pub struct ExtractedChunk {
pub chunk_kind: &'static str,
pub chunk_ordinal: u32,
pub heading_path: Option<String>,
pub title: Option<String>,
pub normalized_text: String,
pub location_kind: LocationKind,
pub line_start: u32,
pub line_end: u32,
pub byte_start: Option<u64>,
pub byte_end: Option<u64>,
pub location_quality: &'static str,
pub parent_idx: Option<usize>,
}Expand description
A chunk ready for the pipeline, with no dependency on orbok-db.
The pipeline layer (orbok-workers) maps this to
orbok_db::repo::ChunkSpec. This keeps orbok-extract free of any
database dependency (RFC-044 14.6).
Fields
chunk_kind: &'static strchunk_ordinal: u32heading_path: Option<String>title: Option<String>normalized_text: Stringlocation_kind: LocationKindline_start: u32line_end: u32byte_start: Option<u64>byte_end: Option<u64>location_quality: &'static strparent_idx: Option<usize>Trait Implementations
Sourceimpl Clone for ExtractedChunk
impl Clone for ExtractedChunk
Sourcefn clone(&self) -> ExtractedChunk
fn clone(&self) -> ExtractedChunk
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractedChunk
impl Debug for ExtractedChunk
Sourceimpl PartialEq for ExtractedChunk
impl PartialEq for ExtractedChunk
Sourcefn eq(&self, other: &ExtractedChunk) -> bool
fn eq(&self, other: &ExtractedChunk) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExtractedChunk